<?php
// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

// Overwrite parent theme background defaults and registers support for WordPress features.
add_action( 'after_setup_theme', 'lalita_background_setup' );
function lalita_background_setup() {
	add_theme_support( "custom-background",
		array(
			'default-color' 		 => 'efeeea',
			'default-image'          => '',
			'default-repeat'         => 'repeat',
			'default-position-x'     => 'left',
			'default-position-y'     => 'top',
			'default-size'           => 'auto',
			'default-attachment'     => '',
			'wp-head-callback'       => '_custom_background_cb',
			'admin-head-callback'    => '',
			'admin-preview-callback' => ''
		)
	);
}

// Overwrite theme URL
function lalita_theme_uri_link() {
	return 'https://wpkoi.com/ishta-wpkoi-wordpress-theme/';
}

// Overwrite parent theme's blog header function
add_action( 'lalita_after_header', 'lalita_blog_header_image', 11 );
function lalita_blog_header_image() {

	if ( ( is_front_page() && is_home() ) || ( is_home() ) ) { 
		$blog_header_image 			=  lalita_get_setting( 'blog_header_image' ); 
		$blog_header_title 			=  lalita_get_setting( 'blog_header_title' ); 
		$blog_header_text 			=  lalita_get_setting( 'blog_header_text' ); 
		$blog_header_button_text 	=  lalita_get_setting( 'blog_header_button_text' ); 
		$blog_header_button_url 	=  lalita_get_setting( 'blog_header_button_url' ); 
		if ( $blog_header_image != '' ) { ?>
		<div class="page-header-image grid-parent page-header-blog" style="background-image: url('<?php echo esc_url($blog_header_image); ?>') !important;">
        	<div class="page-header-noiseoverlay"></div>
        	<div class="page-header-blog-inner">
                <div class="page-header-blog-content-h grid-container">
                    <div class="page-header-blog-content">
                    <?php if ( $blog_header_title != '' ) { ?>
                        <div class="page-header-blog-text">
                            <?php if ( $blog_header_title != '' ) { ?>
                            <h2><?php echo wp_kses_post( $blog_header_title ); ?></h2>
                            <div class="clearfix"></div>
                            <?php } ?>
                        </div>
                    <?php } ?>
                    </div>
                </div>
                <div class="page-header-blog-content page-header-blog-content-b">
                	<?php if ( $blog_header_text != '' ) { ?>
                	<div class="page-header-blog-text">
						<?php if ( $blog_header_title != '' ) { ?>
                        <p><?php echo wp_kses_post( $blog_header_text ); ?></p>
                        <div class="clearfix"></div>
                        <?php } ?>
                    </div>
                    <?php } ?>
                    <div class="page-header-blog-button">
                        <?php if ( $blog_header_button_text != '' ) { ?>
                        <a class="read-more button" href="<?php echo esc_url( $blog_header_button_url ); ?>"><?php echo esc_html( $blog_header_button_text ); ?></a>
                        <?php } ?>
                    </div>
                </div>
            </div>
		</div>
		<?php
		}
	}
}

// Extra cutomizer functions
if ( ! function_exists( 'ishta_customize_register' ) ) {
	add_action( 'customize_register', 'ishta_customize_register' );
	function ishta_customize_register( $wp_customize ) {
				
		// Add Ishta customizer section
		$wp_customize->add_section(
			'ishta_layout_effects',
			array(
				'title' => __( 'Ishta Effects', 'ishta' ),
				'priority' => 1,
				'panel' => 'lalita_layout_panel'
			)
		);
		
		// Blog image border
		$wp_customize->add_setting(
			'ishta_settings[blog_double_border]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'ishta_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'ishta_settings[blog_double_border]',
			array(
				'type' => 'select',
				'label' => __( 'Blog image border', 'ishta' ),
				'choices' => array(
					'enable' => __( 'Enable', 'ishta' ),
					'disable' => __( 'Disable', 'ishta' )
				),
				'settings' => 'ishta_settings[blog_double_border]',
				'section' => 'ishta_layout_effects',
				'priority' => 1
			)
		);
		
		// Navigation hover effect
		$wp_customize->add_setting(
			'ishta_settings[nav_hover]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'ishta_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'ishta_settings[nav_hover]',
			array(
				'type' => 'select',
				'label' => __( 'Navigation hover effect', 'ishta' ),
				'choices' => array(
					'enable' => __( 'Enable', 'ishta' ),
					'disable' => __( 'Disable', 'ishta' )
				),
				'settings' => 'ishta_settings[nav_hover]',
				'section' => 'ishta_layout_effects',
				'priority' => 2
			)
		);
		
		// Header style
		$wp_customize->add_setting(
			'ishta_settings[header_style]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'ishta_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'ishta_settings[header_style]',
			array(
				'type' => 'select',
				'label' => __( 'Ishta header style', 'ishta' ),
				'choices' => array(
					'enable' => __( 'Enable', 'ishta' ),
					'disable' => __( 'Disable', 'ishta' )
				),
				'settings' => 'ishta_settings[header_style]',
				'section' => 'ishta_layout_effects',
				'priority' => 3
			)
		);
		
		//  Ishta header colors
		$wp_customize->add_setting(
			'ishta_settings[ishta_color_1]', array(
				'default' => '#e86a58',
				'type' => 'option',
				'sanitize_callback' => 'ishta_sanitize_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				'ishta_settings[ishta_color_1]',
				array(
					'label' => __( 'Color 1 for Ishta effects', 'ishta' ),
					'section' => 'colors',
					'settings' => 'ishta_settings[ishta_color_1]',
					'priority' => 31
				)
			)
		);
		
		$wp_customize->add_setting(
			'ishta_settings[ishta_color_2]', array(
				'default' => '#efeeea',
				'type' => 'option',
				'sanitize_callback' => 'ishta_sanitize_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				'ishta_settings[ishta_color_2]',
				array(
					'label' => __( 'Color 2 for Ishta effects', 'ishta' ),
					'section' => 'colors',
					'settings' => 'ishta_settings[ishta_color_2]',
					'priority' => 32
				)
			)
		);
		
		$wp_customize->add_setting(
			'ishta_settings[ishta_color_3]', array(
				'default' => '#23362b',
				'type' => 'option',
				'sanitize_callback' => 'ishta_sanitize_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				'ishta_settings[ishta_color_3]',
				array(
					'label' => __( 'Color 3 for Ishta effects', 'ishta' ),
					'section' => 'colors',
					'settings' => 'ishta_settings[ishta_color_3]',
					'priority' => 33
				)
			)
		);
		
		// Logo effect
		$wp_customize->add_setting(
			'ishta_settings[logo_effect]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'ishta_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'ishta_settings[logo_effect]',
			array(
				'type' => 'select',
				'label' => __( 'Ishta logo effect', 'ishta' ),
				'choices' => array(
					'enable' => __( 'Enable', 'ishta' ),
					'disable' => __( 'Disable', 'ishta' )
				),
				'settings' => 'ishta_settings[logo_effect]',
				'section' => 'ishta_layout_effects',
				'priority' => 8
			)
		);
		
		// Fixed side style
		$wp_customize->add_setting(
			'ishta_settings[fixed_side_style]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'ishta_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'ishta_settings[fixed_side_style]',
			array(
				'type' => 'select',
				'label' => __( 'Fixed side socials style', 'ishta' ),
				'choices' => array(
					'enable' => __( 'Enable', 'ishta' ),
					'disable' => __( 'Disable', 'ishta' )
				),
				'settings' => 'ishta_settings[fixed_side_style]',
				'section' => 'ishta_layout_effects',
				'priority' => 9
			)
		);
	}
}

//Sanitize choices.
if ( ! function_exists( 'ishta_sanitize_choices' ) ) {
	function ishta_sanitize_choices( $input, $setting ) {
		// Ensure input is a slug
		$input = sanitize_key( $input );

		// Get list of choices from the control
		// associated with the setting
		$choices = $setting->manager->get_control( $setting->id )->choices;

		// If the input is a valid key, return it;
		// otherwise, return the default
		return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
	}
}

// Sanitize colors. Allow blank value.
if ( ! function_exists( 'ishta_sanitize_hex_color' ) ) {
	function ishta_sanitize_hex_color( $color ) {
	    if ( '' === $color ) {
	        return '';
		}

	    // 3 or 6 hex digits, or the empty string.
	    if ( preg_match('|^#([A-Fa-f0-9]{3}){1,2}$|', $color ) ) {
	        return $color;
		}

	    return '';
	}
}

// Navigation button colors css
if ( ! function_exists( 'ishta_header_style_css' ) ) {
	function ishta_header_style_css() {
		// Get Customizer settings
		$ishta_settings = get_option( 'ishta_settings' );
		
		$ishta_color_1  	 = '#e86a58';
		$ishta_color_2  	 = '#efeeea';
		$ishta_color_3  	 = '#23362b';
		if ( isset( $ishta_settings['ishta_color_1'] ) ) {
			$ishta_color_1 = $ishta_settings['ishta_color_1'];
		}
		if ( isset( $ishta_settings['ishta_color_2'] ) ) {
			$ishta_color_2 = $ishta_settings['ishta_color_2'];
		}
		if ( isset( $ishta_settings['ishta_color_3'] ) ) {
			$ishta_color_3 = $ishta_settings['ishta_color_3'];
		}
		
		$ishta_navcolors = '.ishta-header-style .inside-header{background: linear-gradient(90deg, ' . esc_attr( $ishta_color_1 ) . ' 50.01%, ' . esc_attr( $ishta_color_2 ) . ' 50%);}.ishta-header-style .main-title a, .ishta-header-style .main-title a:hover, .ishta-header-style .main-title a:visited {color: ' . esc_attr( $ishta_color_2 ) . ';}.ishta-fixed-side .lalita-side-left-content .lalita-socials-list li:nth-child(2), .ishta-fixed-side .lalita-side-left-content .lalita-socials-list li:nth-child(4), .ishta-fixed-side .lalita-side-left-content .lalita-socials-list li:nth-child(6), .ishta-fixed-side .lalita-side-left-content .lalita-socials-list li:nth-child(8) {background-color: ' . esc_attr( $ishta_color_1 ) . ';}.ishta-fixed-side .lalita-side-left-content .lalita-side-left-socials ul {border-color: ' . esc_attr( $ishta_color_3 ) . ';}.main-title a .char:before{color:' . esc_attr( $ishta_color_2 ) . ';}.main-title a .char:after{color:' . esc_attr( $ishta_color_1 ) . ';}.main-title a:hover .char{color:' . esc_attr( $ishta_color_3 ) . ';}.main-title a .char:nth-child(2), .main-title a .char:nth-child(4), .main-title a .char:nth-child(6), .main-title a .char:nth-child(8), .main-title a .char:nth-child(10), .main-title a .char:nth-child(12), .main-title a .char:nth-child(14), .main-title a .char:nth-child(16), .main-title a .char:nth-child(18), .main-title a .char:nth-child(20) {color: ' . esc_attr( $ishta_color_3 ) . ';}@media (max-width: 768px) {.ishta-header-style .inside-header{background: ' . esc_attr( $ishta_color_1 ) . ';}}';
		
		return $ishta_navcolors;
	}
}


// The dynamic styles of the parent theme added inline to the parent stylesheet.
// For the customizer functions it is better to enqueue after the child theme stylesheet.
if ( ! function_exists( 'ishta_remove_parent_dynamic_css' ) ) {
	add_action( 'init', 'ishta_remove_parent_dynamic_css' );
	function ishta_remove_parent_dynamic_css() {
		remove_action( 'wp_enqueue_scripts', 'lalita_enqueue_dynamic_css', 50 );
	}
}

// Enqueue this CSS after the child stylesheet, not after the parent stylesheet.
if ( ! function_exists( 'ishta_enqueue_parent_dynamic_css' ) ) {
	add_action( 'wp_enqueue_scripts', 'ishta_enqueue_parent_dynamic_css', 50 );
	function ishta_enqueue_parent_dynamic_css() {
		$css = lalita_base_css() . lalita_font_css() . lalita_advanced_css() . lalita_spacing_css() . lalita_no_cache_dynamic_css() .ishta_header_style_css();

		// escaped secure before in parent theme
		wp_add_inline_style( 'lalita-child', $css );
	}
}

//Adds custom classes to the array of body classes.
if ( ! function_exists( 'ishta_body_classes' ) ) {
	add_filter( 'body_class', 'ishta_body_classes' );
	function ishta_body_classes( $classes ) {
		// Get Customizer settings
		$ishta_settings = get_option( 'ishta_settings' );
		
		$nav_hover  		 = 'enable';
		$header_style  	 	 = 'enable';
		$logo_effect  	 	 = 'enable';
		$fixed_side_style	 = 'enable';
		$blog_double_border	 = 'enable';
		
		if ( isset( $ishta_settings['nav_hover'] ) ) {
			$nav_hover = $ishta_settings['nav_hover'];
		}
		
		if ( isset( $ishta_settings['header_style'] ) ) {
			$header_style = $ishta_settings['header_style'];
		}
		
		if ( isset( $ishta_settings['logo_effect'] ) ) {
			$logo_effect = $ishta_settings['logo_effect'];
		}
		
		if ( isset( $ishta_settings['fixed_side_style'] ) ) {
			$fixed_side_style = $ishta_settings['fixed_side_style'];
		}
		
		if ( isset( $ishta_settings['blog_double_border'] ) ) {
			$blog_double_border = $ishta_settings['blog_double_border'];
		}
		
		// Navigation hover effect
		if ( $nav_hover != 'disable' ) {
			$classes[] = 'ishta-nav-hover';
		}
		
		// Header style
		if ( $header_style != 'disable' ) {
			$classes[] = 'ishta-header-style';
		}
		
		// Logo effect
		if ( $logo_effect != 'disable' ) {
			$classes[] = 'ishta-logo-effect';
		}
		
		// Fixed side style
		if ( $fixed_side_style != 'disable' ) {
			$classes[] = 'ishta-fixed-side';
		}
		
		// Blog image border
		if ( $blog_double_border != 'disable' ) {
			$classes[] = 'ishta-blog-double-border';
		}
		
		return $classes;
	}
}

if ( ! function_exists( 'ishta_scripts' ) ) {
	add_action( 'wp_enqueue_scripts', 'ishta_scripts' );
	/**
	 * Enqueue script
	 */
	function ishta_scripts() {
		
		$ishta_settings = get_option( 'ishta_settings' );
		
		$logo_effect = 'enable';
		if ( isset( $ishta_settings['logo_effect'] ) ) {
			$logo_effect = $ishta_settings['logo_effect'];
		}
		
		if ( $logo_effect != 'disable' ) {
			wp_enqueue_style( 'ishta-splitting-css', esc_url( get_stylesheet_directory_uri() ) . "/css/splitting.min.css", false, LALITA_VERSION, 'all' );
			wp_enqueue_script( 'ishta-splitting-js', esc_url( get_stylesheet_directory_uri() ) . "/js/splitting.min.js", array( 'jquery'), LALITA_VERSION, true );
		}
		
	}
}